@@ -2,10 +2,12 @@ from json import dumps
 
 import click
 
-from ..decorators import loses_interactivity, require_login
-from ..helpers.ec2.factory import get_ec2_client
-from ..helpers.global_options import GlobalOptions
-from ..helpers.options import resource_argument
+from sym.cli.decorators import loses_interactivity, require_login, skip_analytics
+from sym.cli.helpers.ec2.factory import get_ec2_client
+from sym.cli.helpers.global_options import GlobalOptions
+from sym.cli.helpers.options import resource_argument
+from sym.cli.saml_clients.saml_client_factory import SAMLClientFactory
+
 from .sym import sym
 
 
@@ -14,8 +16,9 @@ from .sym import sym
 @resource_argument
 @click.argument("host")
 @click.make_pass_decorator(GlobalOptions)
-@loses_interactivity
+@skip_analytics
 @require_login
+@loses_interactivity
 def host_to_instance(
     options: GlobalOptions,
     resource: str,
@@ -23,7 +26,7 @@ def host_to_instance(
     json: bool,
 ) -> None:
     """Get the Instance ID of a HOST associated with a Sym RESOURCE."""
-    client = options.create_saml_client(resource)
+    client = SAMLClientFactory.create_saml_client(resource, options)
     instance = get_ec2_client(client).load_instance_by_alias(host)
     if json:
         click.echo(dumps({"instance": instance.instance_id, "region": instance.region}))
