@@ -1,13 +1,13 @@
-from pathlib import Path
-
 import click
 
-from ..decorators import loses_interactivity, require_bins, require_login
-from ..helpers.global_options import GlobalOptions
-from ..helpers.options import resource_argument
-from ..helpers.ssh import maybe_gen_ssh_key
-from ..saml_clients.aws_profile import AwsCredentialsPath
-from .sym import sym
+from sym.cli.actions.action_registry import ActionRegistry
+from sym.cli.data.request_data import RequestData
+from sym.cli.decorators import command_require_bins, loses_interactivity, require_login
+from sym.cli.helpers.global_options import GlobalOptions
+from sym.cli.helpers.options import resource_argument
+from sym.cli.saml_clients.aws_profile import AwsCredentialsPath
+
+from .sym import sym  # TODO: this should be an absolute import
 
 
 @sym.command(short_help="Write out AWS credentials")
@@ -26,9 +26,9 @@ from .sym import sym
     show_default=True,
 )
 @click.make_pass_decorator(GlobalOptions)
-@loses_interactivity
-@require_bins("aws", "session-manager-plugin")
+@command_require_bins("aws", "session-manager-plugin")
 @require_login
+@loses_interactivity
 def write_creds(options: GlobalOptions, resource: str, path: str, profile: str) -> None:
     """Write out approved credentials for the specified Sym RESOURCE to
     a profile in your AWS credentials file.
@@ -37,6 +37,11 @@ def write_creds(options: GlobalOptions, resource: str, path: str, profile: str)
     Example:
         `sym write-creds test --profile my-test-profile --path path/to/credentials`
     """
-    client = options.create_saml_client(resource)
-    client.write_creds(path=Path(path), profile=profile)
-    maybe_gen_ssh_key(client)
+
+    request_data = RequestData(
+        action="write_creds",
+        resource=resource,
+        global_options=options,
+        params={"path": path, "profile": profile},
+    )
+    ActionRegistry.execute(request_data)
