@@ -26,6 +26,7 @@ from .helpers.keywords_to_options import Argument, keywords_to_options
 from .helpers.os import has_command
 from .helpers.sentry import set_scope_context_os, set_scope_tag_org, set_scope_user
 from .helpers.tee import Tee
+from .saml_clients.saml_client_factory import SAMLClientFactory
 
 # Typing support for decorators is still in need of a lot of work:
 # https://github.com/python/mypy/issues/3157. So the current grossness
@@ -40,18 +41,26 @@ def run_subprocess(
     func: Callable[..., Iterator[Sequence[Argument]]]
 ) -> Callable[..., Optional[Sequence[Optional[str]]]]:
     @wraps(func)
-    @click.make_pass_decorator(GlobalOptions)
     def impl(
-        options: GlobalOptions,
         *args: Any,
-        censor_=False,
-        capture_output_=False,
-        silence_stderr_=True,
-        input_=None,
+        censor_: bool = False,
+        capture_output_: bool = False,
+        silence_stderr_: bool = True,
+        input_: str = None,
+        run_subprocess_options_: Optional[GlobalOptions] = None,
         **kwargs: Any,
     ) -> Optional[Sequence[Optional[str]]]:
+
+        options = run_subprocess_options_
+        if not options:
+            # Ideally we will never need to access click at this level and
+            # will instead always pass in options. This is for backward
+            # compatibility as we refactor.
+            options = click.get_current_context().find_object(GlobalOptions)
+
         outputs = []
         tee = bool(options.log_dir) and not censor_
+
         for command in func(*args, **kwargs):
             command = keywords_to_options(command)
             options.dprint(f"exec: {shlex.join(command)}\n")
@@ -84,14 +93,21 @@ def intercept_errors(
 ) -> Callable[[F], F]:
     def decorate(fn: F) -> F:
         @wraps(fn)
-        @click.make_pass_decorator(GlobalOptions)
         def wrapped(
-            options: GlobalOptions,
             *args: Any,
             quiet_: bool = False,
             suppress_: bool = False,
+            intercept_errors_options_: Optional[GlobalOptions] = None,
             **kwargs: Any,
         ) -> Any:
+
+            options = intercept_errors_options_
+            if not options:
+                # Ideally we will never need to access click at this level and
+                # will instead always pass in options. This is for backward
+                # compatibility as we refactor.
+                options = click.get_current_context().find_object(GlobalOptions)
+
             try:
                 return fn(*args, **kwargs)
             except CalledProcessError as err:
@@ -111,10 +127,16 @@ def intercept_errors(
     return decorate
 
 
-# See: https://click.palletsprojects.com/en/7.x/commands/#decorating-commands
+def command_require_bins(*bins: str) -> Callable[[F], F]:
+    """Decorator to declare that the Click command being defined requires
+    specific binaries to run successfully.
 
+    See: https://click.palletsprojects.com/en/7.x/commands/#decorating-commands
+
+    Raises:
+        CliError: if any required bin could not be found
+    """
 
-def require_bins(*bins: str) -> Callable[[F], F]:
     def decorate(fn: F) -> F:
         @click.pass_context
         @wraps(fn)
@@ -129,6 +151,29 @@ def require_bins(*bins: str) -> Callable[[F], F]:
     return decorate
 
 
+def require_bins(*bins: str) -> Callable[[F], F]:
+    """Decorator to declare that the function being defined requires
+    specific binaries to run successfully.
+
+    Use this decorator to require bins on functions without Click context.
+
+    Raises:
+        CliError: if any required bin could not be found
+    """
+
+    def decorate(fn: F) -> F:
+        @wraps(fn)
+        def wrapped(*args: Any, **kwargs: Any) -> Any:
+            for binary in bins:
+                if not has_command(binary):
+                    raise CliError(f"Unable to find {binary} in your path!")
+            return fn(*args, **kwargs)
+
+        return wrapped
+
+    return decorate
+
+
 def require_login(fn: F) -> F:
     @click.pass_context
     @wraps(fn)
@@ -145,14 +190,26 @@ def loses_interactivity(fn: F) -> F:
     @wraps(fn)
     def wrapped(context: click.Context, *args: Any, **kwargs: Any) -> Any:
         if (resource := kwargs.get("resource")) :
-            context.find_object(GlobalOptions).create_saml_client(
-                resource
-            ).ensure_session()
+            saml_client = SAMLClientFactory.create_saml_client(
+                resource, context.find_object(GlobalOptions)
+            )
+            saml_client.ensure_session()
         return context.invoke(fn, *args, **kwargs)
 
     return cast(F, require_login(wrapped))
 
 
+def skip_analytics(fn: F) -> F:
+    @click.pass_context
+    @wraps(fn)
+    def wrapped(context: click.Context, *args: Any, **kwargs: Any) -> Any:
+        options = context.ensure_object(GlobalOptions)
+        options.disable_analytics = True
+        return context.invoke(fn, *args, **kwargs)
+
+    return cast(F, wrapped)
+
+
 def setup_segment(**kwargs: Any) -> Callable[[F], F]:
     analytics.default_client = analytics.client.Client(send=PROD_MODE, **kwargs)
 
@@ -160,7 +217,7 @@ def setup_segment(**kwargs: Any) -> Callable[[F], F]:
         @click.pass_context
         @wraps(fn)
         def wrapped(context: click.Context, *args: Any, **kwargs: Any) -> Any:
-            segment.identify()
+            segment.identify(context.find_object(GlobalOptions))
             return context.invoke(fn, *args, **kwargs)
 
         return cast(F, wrapped)
