@@ -70,6 +70,30 @@ PARAMS: Dict[str, OrgParams] = {
                 arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-staging",
                 ansible_bucket="launchdarkly-sym-ansible-staging-intuit",
             ),
+            "production_apac": Profile(
+                display_name="Production: APAC",
+                region="ap-southeast-1",
+                arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-production",
+                ansible_bucket="launchdarkly-sym-ansible-production",
+            ),
+            "production_euw1": Profile(
+                display_name="Production: EU West 1",
+                region="eu-west-1",
+                arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-production",
+                ansible_bucket="launchdarkly-sym-ansible-production",
+            ),
+            "staging_apac": Profile(
+                display_name="Staging: APAC",
+                region="ap-southeast-1",
+                arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-staging",
+                ansible_bucket="launchdarkly-sym-ansible-staging",
+            ),
+            "staging_euw1": Profile(
+                display_name="Staging: EU West 1",
+                region="eu-west-1",
+                arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-staging",
+                ansible_bucket="launchdarkly-sym-ansible-staging",
+            ),
         },
     },
     "sym": {
@@ -92,6 +116,11 @@ PARAMS: Dict[str, OrgParams] = {
                 region="us-east-1",
                 arn="arn:aws:iam::838419636750:role/SSMTestRole",
             ),
+            "test_euw1": Profile(
+                display_name="Test: EU West 1",
+                region="eu-west-1",
+                arn="arn:aws:iam::838419636750:role/SSMTestRole",
+            ),
             "test-custom": Profile(
                 display_name="TestCustom",
                 region="us-east-1",
